#
# spec file for package bwidget
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bwidget
BuildRequires:  dos2unix
BuildRequires:  tcl
Version:        1.9.14
Release:        1.8
Summary:        A Set of Megawidgets for Tcl/Tk
License:        BSD-3-Clause
Group:          Development/Libraries/Tcl
URL:            https://core.tcl-lang.org/bwidget
BuildArch:      noarch
Requires:       tk
Source0:        https://sourceforge.net/projects/tcllib/files/BWidget/%{version}/bwidget-%{version}.tar.gz

%description
Add useful and nice-looking widgets to your interfaces with the BWidget
Toolkit, a set of native Tk 8.x Widgets using Tcl8.x namespaces. The
BWidgets have a professional look and feel as in other well-known
toolkits (Tix or Incr Widget). However, the concept is radically
different because everything is native. There is no platform
compilation and no compiled extension libraries are needed. The code is
in pure Tcl/Tk.

%prep
%setup -q -n %{name}-%version

find . -name \*.txt -print0 | xargs -0 dos2unix

%build

%install
dir=%buildroot%tcl_noarchdir/%name%version
mkdir -m755 -p $dir
cp -a *.tcl images lang $dir
chmod a+x demo/demo.tcl

%files
%defattr(-,root,root)
%doc demo BWman/* ChangeLog CHANGES.txt LICENSE.txt README.txt
%tcl_noarchdir

%changelog
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.9.14:
    spinbox.tcl: fix error about unsupported option
  - disabledforeground when using themed widgets.
    Thanks to Gerhard Reithofer and Christian Werner.
    Ticket [071fc80f14]
    mainframe.tcl: Add optional parameter "Top" to internal
    function "MainFrame::_create_menubar" to allow to use
    a menu button for the main menu (Hack).
    The mainframe may be initialized with "- menu {}".
    Then, the menubutton may be created and the menu may
    by added by:
    MainFrame::_create_menubar .mf $mitems $menubutton.
    Allow to skip a main menu level by empty menu label.
    Purpose: support commands/checkboxes at first level.
    scrollframe.tcl: use Tk8.7 TIP 518 virtual event
    <<NoManagedChild>> to resize client frame to 1x1 when
    last child is unmapped.
    dialog.c: For Unix, also Bind KP_Enter for default dialog
    button invokation. Ticket [3e31f04367].
    Thanks to Jos for the proposal.
    Spanish translation enhanced by Neko.
    Ticket [a947e33526]
    color.tcl: replace the help widget by balloons bound to the
    widgets. Ticket [2cc70ce1cb]
    color.tcl: New option -command allows to get a callback
    when the user does an unvalidated choice.
    New option -background and command SelectColor for
    window background.
    TitleFrames, Dynamic help and Aqua native buttons used.
    Show current choice by highlighting, not focus, to avoid
    conflict with keyboard traversal.
    Shows entry widget for numerical color input/output.
    New option -help to show a help area.
    Patch by Keith J. Nash
    Ticket [75101bf5ce]
    Translators: Jima (es), Vogel (fr), Marcus (nl), Ian (da)
    Ticket [a947e33526]
    notebook.tcl (+man,demo): Add possibility to NoteBook
    to add an image at the right of each tab.
    Ticket [15e19fe9ec]. Patch by Keith J. Nash.
    MessageDlg.html: Documented the use of the native widget for
    "MessageDlg -type !user" and the limited set of recognized
    options. Ticket [8edade3cea] by Gerhard Reithofer
    listbox.tcl: Listbox did not scroll to current item on
    startup. Ticket [ae238d5a7]
    lang/da.rc, lang/es.rc, lang/fr.rc, lang/no.rc:
    Translations non portable on utf-8 systems.
    File encoding changed to utf-8. Ticket [6c91e43d76]
    tree.tcl: Tree lines are black by default even if background
    is black. Ticket [ed4c1dab46]
    listbox.tcl: 8.4 compatibility was broken due to the use of
    min/max math functions. Ticket [0aef856302]
    dynhelp.tcl: Drop the assumption that all windows
    screen are the same size (of fix dated 2009-06-26)
    and use the virtual screen information to place the bubble
    help. Ticket [b64e03e548].
* Sun Nov  1 2015 p.drouand@gmail.com
- Update to version 1.9.9
  * widget.tcl: Widget::define got new parameter -namespace, allowing
    megawidget namespace be different to class name. This allows lower
    case namespace names. Ticket [023a631b20]
* Wed Dec 24 2014 p.drouand@gmail.com
- Update to version 1.9.8
  + widget.tcl: Widget::which errors when option not present.
    Ticket [397db23424]
  + widget.tcl: Don't invoke unqualified upvar in callers
    scope. Ticket [046fa04231]
  + widget.tcl: Don't double creation of temporary widget for
  + default values retrieval. Use result of _get_tkwidget_options
    instead. Ticket [393b67ab19]
  + widget.tcl: New procedure Widget::which (as in [namespace which]),
    that returns the fully qualified name for a widget option or
    widget variable. Ticket [a8705e5fd9]
  + widget.tcl: Remove unneeded upvar. Ticket [43f93e0a97]
  + widget.tcl et al: remove apparently unused procedure
    Widget::syncoptions and all calls. Ticket [3c2b8eafc6]
  + scrollframe.tcl: Make -constrainedwidth 1 and
  - constrainedheight 1 work together. Ticket [2fa44401d5]
  + widget.tcl: Remove temporary widget. Ticket [6cd041bcc1]
  + combobox.tcl: Themed ComboBox color specifications
    are honored. Ticket [6c6704e40f]
  + combobox.tcl: Fails in themed mode with "unknown
    option -bg". Patch solves this but listbox items
    are white on white when "-foreground" is specified.
    Ticket [6632134ce9]
  + listbox.tcl: Update on option -deltay added.
    Set x0 to 2 to make highlight work and look nice for
    listbox with image.
    Take image into account to show selection.
    Ticket [ff1787af9c]
  + scrollw.tcl: Raise scrolled window if it is below in
    the window hierarchy. Ticket [ff1787af9c]
  + dynhelp.tcl: Sometimes the tooltip does not occur under
    gnome/metacity on ubuntu. Ticket [a588d2f800]
- Add Url to project home
* Thu Aug  9 2012 max@suse.com
- New version 1.9.6:
  * listbox.tcl ListBox::selection Only redraw if selection
    changed.
  * entry.tcl, BWMan/entry.tcl checkbox.tcl Themed mode: Invoking
    "configure" without arguments results in errors that non-ttk
    options are not present.
  * Removed Entry options: -background -foreground -relief
  - borderwidth -fg -bg -bd.
  * entry.tcl mapped entry option -state to ttk::entry state in
    themed mode to make state change visible.
  * BWMan/ListBox.html documented options -selectfill and
  - autofocus as read-only.
  * widget.tcl (Widget::focusOK) fixed list with update.
    Arises, if a ttk widget with a widget path with spaces is the
    next widget.
* Wed Feb 29 2012 gschlotter@suse.com
- Upgrade to version 1.9.5.
- /images/CVS/ doesn't exist in this version
- source name changed to bwidget from BWidget
- included dos2unix to erease an error from a txt file
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Wed Jul 29 2009 max@suse.de
- Bugfix release: 1.9.0.
  * MainFrame: getmenustate method
  * ScrollFrame: follows much better when contents size changes
  * ComboBox: Posting, Keyboard, not unique contents return,
    Mac X11 and aqua, text selection handling.
  * Listbox: item deletion error
  * PasswdDlg: disabled password handling
  * Balloon Help: Placement on borders and on multiple screens
    (as far as possible)
- Potential incompatibilities:
  * Option data base entry for "MessageDlg -text" changed
    from "*MessageDlg.frame.msg.message"
    to "*MessageDlg.frame.msg.text"
* Thu Apr 17 2008 max@suse.de
- New version 1.8.0 from CVS as of 2007-10-31.
- Many bug fixes, new translations and adjustments for Tk 8.5.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jun 17 2005 max@suse.de
- Moved script library to /usr/share/tcl .
* Fri Jan 30 2004 max@suse.de
- new version: 1.7.0 + some newer fixes from CVS.
- building as a non-root user.
* Mon May 26 2003 max@suse.de
- new version: 1.6
* Thu Jun 13 2002 max@suse.de
- new version: 1.4.1
* Mon Feb 25 2002 max@suse.de
- fixed permissions of library and demo scripts.
* Mon Jul 23 2001 max@suse.de
- new version 1.3.1
- changed RPM group to Development/Libraries/Tcl
- using buildroot
- BuildArchitectures: noarch
- added missing ./config subdir and it's contents.
* Sat Dec  9 2000 nashif@suse.de
- sorted
* Tue Oct 12 1999 max@suse.de
- new package (version 1.2.1)
